<?php

class GoalTracking{

	public static function IsGoal($post_id) {
		$isGoal = 1 == intval(get_post_meta($post_id,'tallyopia_isgoal',true),10);
		return $isGoal;
	}

	public static function AddGoalBoxes(){
		add_meta_box('tallyopia-goal-box','Tallyopia Goal',array('GoalTracking','GetGoalBoxHTML'),'post','side','high',null);
		add_meta_box('tallyopia-goal-box','Tallyopia Goal',array('GoalTracking','GetGoalBoxHTML'),'page','side','high',null);
	}

	public static function GetGoalBoxHTML($post) {
		$type = $post->post_type;
		$isGoal = GoalTracking::IsGoal($post->ID);
		$checked = $isGoal ? 'checked' : '';

		//	Display the form
		wp_nonce_field('save_tallyopia_isgoal','save_tallyopia_isgoal_field');
  		echo "<input type='checkbox' name='tallyopia_isgoal' id='tallyopia_isgoal' value='isgoal' {$checked}/>&nbsp;";
		echo '<label for="tallyopia_isgoal_field">';
       	echo "Is this {$type} a goal?";
  		echo '</label> ';
  		//var_dump(get_post_meta($post->ID,'tallyopia_isgoal',true),true);
	}

	public static function SaveGoalBox($post_id){
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {return;}
		if (!wp_verify_nonce($_POST['save_tallyopia_isgoal_field'],'save_tallyopia_isgoal')) {return;}

		// Check permissions
		$perms = array();
		$perms['page'] = 'edit_page';
		$perms['post'] = 'edit_post';
		$postType = $_POST['post_type'];
		if (!array_key_exists($postType,$perms)) {return;}
		$capability = $perms[$postType];
		if (!current_user_can($capability,$post_id)){return;}

		//	If we're here, we can save the data
		$value = $_POST['tallyopia_isgoal'];
		$saveValue = 0;
		if ('isgoal' == $value) {$saveValue = 1;}
		update_post_meta($post_id,'tallyopia_isgoal',$saveValue);
	}

	private static function ListGoals() {
		$parts = array();

		//	Get all the pages that are goals and display in a table
		global $wpdb;
		$q = 	"SELECT P.ID as ID, P.post_title as post_title"
				. " FROM {$wpdb->prefix}postmeta AS M, {$wpdb->prefix}posts AS P "
				. " WHERE M.meta_key =  'tallyopia_isgoal' "
				. " AND M.meta_value =1 "
				. " AND P.ID = M.post_id";
		$results = $wpdb->get_results($q,ARRAY_A);

		$parts []= '<div style="width:80%">';
		$parts []= '<table class="widefat" >';
		$parts []='<thead><tr><th>Goal Page</th><th>View</th><th>Edit</th></tr></thead>';
		$parts []='<tfoot><tr><th>Goal Page</th><th>View</th><th>Edit</th></tr></tfoot>';
		$parts []='<tbody>';
		foreach ($results as $r) {
			$editLink = get_edit_post_link($r['ID']);
			$viewLink = get_permalink($r['ID']);

			$parts []='<tr>';
			$parts []="<td>{$r['post_title']}</td>";
			$parts []= "<td><a href='{$viewLink}'>View</a></td>";
			$parts []= "<td><a href='{$editLink}'>Edit</a></td>";
			$parts []='</tr>';

		}
		$parts []='</tbody>';
		$parts []='</table>';

		//	Add some text to explain things
		$numGoals 	= count($results);
		$goals		= 1==$numGoals ? 'goal':'goals';
		$parts []=<<<EOD
		<ul>
			<li><strong>{$numGoals} {$goals} found.</strong><br/><br/></li>
			<li><strong>To view the Goal Analysis Reports, click on the Goal Analysis link above the Goals table.<br/><br/></strong></li>
			<li>To add a goal, edit the page or post you'd like to make into a goal and check the "Is this post a goal"
			checkbox found in the Tallyopia Goal box.  If you don't see a Tallyopia Goal box when editing a post or page,
			click "Screen Options" and make sure that "Tallyopia Goal' is selected.
			<br/><br/>
			</li>

		</ul>
EOD;

		$parts []= '</div>';
		return implode('',$parts);
	}

	public static function RenderGoalsConfigurePage($tabString){
		$goalsString = GoalTracking::ListGoals();
		$str = <<<EOD
		<style>
		.inlineItems {
			display:inline;
			float:left;
			font-weight:bold;
		}
		</style>
		<div id='icon-themes' class='icon32'><br /></div><h2>Tallyopia Goals</h2>
		<div id='tabs'>
			<ul class="inlineItems">
				<li class="inlineItems"><a href='#listGoals'>Goals</a></li>
				<li class="inlineItems">&nbsp;|&nbsp;</li>
				<li class="inlineItems"><a href='#analysis'>Goal Analysis</a></li>
			</ul>
			<div id='listGoals'>
				{$goalsString}
			</div>
			<div id='analysis'>
				{$tabString}
			</div>


		</div>

		<script type="text/javascript" src="http://ajax.googleapis.com/ajax/libs/jqueryui/1.8.16/jquery-ui.min.js"></script>
		<script type='text/javascript'>
			jQuery(document).ready(
				function() {
					jQuery("#tabs").tabs({
											ajaxOptions: {
												error: function( xhr, status, index, anchor ) {
													jQuery(anchor.hash).html(
														"Couldn't load this tab. We'll try to fix this as soon as possible. " +
														"If this wouldn't be a demo."
													);
												}
											}
										});
							}
			);
		</script>

EOD;
		echo $str;
	}
}



?>